# bio-jtools

Various bioinformatics tools in one package

[![Conda](https://img.shields.io/conda/pn/jrhawley/bio-jtools.svg)](https://anaconda.org/jrhawley/bio-jtools)
[![Python version](https://img.shields.io/pypi/pyversions/bio-jtools.svg)](https://pypi.python.org/pypi/bio-jtools)
[![PyPI](https://img.shields.io/pypi/v/bio-jtools.svg)](https://pypi.python.org/pypi/bio-jtools)
[![Wheel](https://img.shields.io/pypi/wheel/bio-jtools.svg)](https://pypi.python.org/pypi/bio-jtools)
[![Implementation](https://img.shields.io/pypi/implementation/bio-jtools.svg)](https://pypi.python.org/pypi/bio-jtools)

[![Python build](https://github.com/jrhawley/bio-jtools/workflows/Python%20packaging/badge.svg)](https://github.com/jrhawley/bio-jtools/actions?workflow=Python+packaging)
[![Conda build](https://github.com/jrhawley/bio-jtools/workflows/Conda%20packaging/badge.svg)](https://github.com/jrhawley/bio-jtools/actions?workflow=Conda+packaging)

## Usage

```shell
jtools <sub-command>
```

## Installation

```shell
# pip
pip install bio-jtools

# conda
conda install -c jrhawley bio-jtools
```

## Documentation

For detailed documentation, see the [GitHub Wiki](https://github.com/jrhawley/bio-jtools/wiki).
